import logging

from django import forms
from django.core.urlresolvers import reverse
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _

logger = logging.getLogger(__name__)


class SecuredFileWidget(forms.FileInput):
    """A FileField Widget that shows secure file link"""

    def __init__(self, attrs=None):
        if attrs is None:
            attrs = {}
        super(SecuredFileWidget, self).__init__(attrs)

    def render(self, name, value, attrs=None):
        output = []
        if value and hasattr(value, "url"):
            url = reverse('web.views.uploaded_files') + '?file=' + unicode(value)
            out = u'<a href="{}">{}</a><br />{} '
            output.append(out.format(url, _(u'Download'), _(u'Change:')))
        output.append(super(SecuredFileWidget, self).render(name, value, attrs))
        return mark_safe(u''.join(output))
